<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Admin\Controller;

use Admin\Data\Common;
use Admin\Form\LanguageForm;
use Doctrine\ORM\EntityManager;
use Laminas\Mvc\I18n\Translator;

class LanguageController extends AdminActionController
{
    private $translator;
    private $entityManager;

    private $languageConfig;

    public function __construct(
        Translator $translator,
        EntityManager $entityManager
    )
    {
        $this->translator = $translator;
        $this->entityManager = $entityManager;

        $this->languageConfig = Common::readConfigFile('language');

    }

    public function indexAction(): array
    {
        return ['languageArray' => $this->languageConfig];
    }

    public function editAction()
    {
        $languageCode = $this->params()->fromRoute('id', '');
        if (empty($languageCode) || !isset($this->languageConfig['fLanguage'][$languageCode])) {
            $this->flashMessenger()->addWarningMessage($this->translator->translate('该语言不存在!'));
            return $this->redirect()->toRoute('language');
        }

        $form = new LanguageForm($languageCode);
        if($this->getRequest()->isPost()) {
            $data = $this->params()->fromPost();
            $form->setData($data);
            if ($form->isValid()) {
                $data = $form->getData();
                if ($data['defaultLanguage'.$languageCode] == 1 && $data['languageState'.$languageCode] != 1) {
                    $this->flashMessenger()->addWarningMessage($this->translator->translate('默认语言不能是禁用状态!'));
                    return $this->redirect()->toRoute('language', ['action' => 'edit', 'id' => $languageCode]);
                }
                if ($data['defaultLanguage'.$languageCode] != 1 && $languageCode == SHOP_FONT_LANGUAGE) {
                    $this->flashMessenger()->addWarningMessage($this->translator->translate('不能取消默认，可以设置其他语言默认!'));
                    return $this->redirect()->toRoute('language', ['action' => 'edit', 'id' => $languageCode]);
                }
                if ($data['languageState'.$languageCode] != 1 && $languageCode == SHOP_FONT_LANGUAGE) {
                    $this->flashMessenger()->addWarningMessage($this->translator->translate('不能将默认语言的状态设置为 禁用!'));
                    return $this->redirect()->toRoute('language', ['action' => 'edit', 'id' => $languageCode]);
                }


                $shopDefaultLanguageCode = $data['defaultLanguage'.$languageCode] == 1 ? $languageCode : SHOP_FONT_LANGUAGE;
                $shopLanguageStr = "'".implode("','", array_filter(SHOP_LANGUAGE))."',";
                $shopLanguageStr = $data['languageState'.$languageCode] == 1 ? (in_array($languageCode, SHOP_LANGUAGE) ? $shopLanguageStr : $shopLanguageStr . "'" . $languageCode . "',") : str_replace("'".$languageCode."',", '', $shopLanguageStr);

                $languagePhp = "<?php\n";
                $languagePhp .= "const SHOP_ADMIN_LANGUAGE = '".SHOP_ADMIN_LANGUAGE."';\n";
                $languagePhp .= "const ADMIN_LANGUAGE = ['".implode("','", ADMIN_LANGUAGE)."'];\n";
                $languagePhp .= "const SHOP_FONT_LANGUAGE = '".$shopDefaultLanguageCode."';\n";
                $languagePhp .= "const SHOP_FONT_DOMAIN = [".$this->fLanguageDomain($languageCode, $this->languageConfig['language'], $data['domain'.$languageCode])."];\n";
                $languagePhp .= "const SHOP_LANGUAGE = [".rtrim($shopLanguageStr, ',')."];\n";
                $languagePhp .= "const SHOP_LANGUAGE_ARRAY = [".$this->fLanguageStr($this->languageConfig['fLanguage'])."];\n";
                file_put_contents('data/shopLanguage.php', $languagePhp);
                Common::opcacheInvalidate('data/shopLanguage.php');

                $this->adminCommon()->addOperLog($this->translator->translate('前台语言设置完成!'), $this->translator->translate('语言设置'));
                return $this->redirect()->toRoute('language');
            }
        }

        $shopDomainArray = defined('SHOP_FONT_DOMAIN') ? SHOP_FONT_DOMAIN : [];
        $form->setData([
            'defaultLanguage'.$languageCode => SHOP_FONT_LANGUAGE == $languageCode ? 1 : 0,
            'languageState'.$languageCode => in_array($languageCode, SHOP_LANGUAGE) ? 1 : 0,
            'domain'.$languageCode => empty($shopDomainArray) ? '' : array_search($languageCode, $shopDomainArray)
        ]);

        return ['form' => $form, 'languageArray' => $this->languageConfig, 'languageCode' => $languageCode];
    }

    public function systemLanguageAction(): array
    {
        return ['languageArray' => $this->languageConfig];
    }

    public function editSystemLanguageAction()
    {
        $languageCode = $this->params()->fromRoute('id', '');
        if (empty($languageCode) || !isset($this->languageConfig['aLanguage'][$languageCode])) {
            $this->flashMessenger()->addWarningMessage($this->translator->translate('该语言不存在!'));
            return $this->redirect()->toRoute('language', ['action' => 'systemLanguage']);
        }

        $form = new LanguageForm($languageCode);
        if($this->getRequest()->isPost()) {
            $data = $this->params()->fromPost();
            $form->setData($data);
            if ($form->isValid()) {
                $data = $form->getData();
                if ($data['defaultLanguage'.$languageCode] == 1 && $data['languageState'.$languageCode] != 1) {
                    $this->flashMessenger()->addWarningMessage($this->translator->translate('默认语言不能是禁用状态!'));
                    return $this->redirect()->toRoute('language', ['action' => 'editSystemLanguage', 'id' => $languageCode]);
                }
                if ($data['defaultLanguage'.$languageCode] != 1 && $languageCode == SHOP_ADMIN_LANGUAGE) {
                    $this->flashMessenger()->addWarningMessage($this->translator->translate('不能取消默认，可以设置其他语言默认!'));
                    return $this->redirect()->toRoute('language', ['action' => 'editSystemLanguage', 'id' => $languageCode]);
                }
                if ($data['languageState'.$languageCode] != 1 && $languageCode == SHOP_ADMIN_LANGUAGE) {
                    $this->flashMessenger()->addWarningMessage($this->translator->translate('不能将默认语言的状态设置为 禁用!'));
                    return $this->redirect()->toRoute('language', ['action' => 'editSystemLanguage', 'id' => $languageCode]);
                }

                $sysDefaultLanguageCode = $data['defaultLanguage'.$languageCode] == 1 ? $languageCode : SHOP_ADMIN_LANGUAGE;
                $sysLanguageStr = "'".implode("','", array_filter(ADMIN_LANGUAGE))."',";
                $sysLanguageStr = $data['languageState'.$languageCode] == 1 ? (in_array($languageCode, ADMIN_LANGUAGE) ? $sysLanguageStr : $sysLanguageStr . "'" . $languageCode . "',") : str_replace("'".$languageCode."',", '', $sysLanguageStr);

                $languagePhp = "<?php\n";
                $languagePhp .= "const SHOP_ADMIN_LANGUAGE = '".$sysDefaultLanguageCode."';\n";
                $languagePhp .= "const ADMIN_LANGUAGE = [".rtrim($sysLanguageStr, ',')."];\n";
                $languagePhp .= "const SHOP_FONT_LANGUAGE = '".SHOP_FONT_LANGUAGE."';\n";
                $languagePhp .= "const SHOP_LANGUAGE = ['".implode("','", SHOP_LANGUAGE)."'];\n";
                $languagePhp .= "const SHOP_LANGUAGE_ARRAY = [".$this->fLanguageStr($this->languageConfig['fLanguage'])."];\n";
                file_put_contents('data/shopLanguage.php', $languagePhp);
                Common::opcacheInvalidate('data/shopLanguage.php');

                $this->adminCommon()->addOperLog($this->translator->translate('前台语言设置完成!'), $this->translator->translate('语言设置'));
                return $this->redirect()->toRoute('language', ['action' => 'systemLanguage']);
            }
        }

        $form->setData(['defaultLanguage'.$languageCode => SHOP_ADMIN_LANGUAGE == $languageCode ? 1 : 0, 'languageState'.$languageCode => in_array($languageCode, ADMIN_LANGUAGE) ? 1 : 0]);

        return ['form' => $form, 'languageArray' => $this->languageConfig, 'languageCode' => $languageCode];
    }

    /**
     * @param $fLanguage
     * @return string
     */
    private function fLanguageStr($fLanguage): string
    {
        $fLanguageStr = '';
        foreach ($fLanguage as $key => $value) {
            $fLanguageStr .= "'".$key."' => '".$value."',";
        }

        return rtrim($fLanguageStr, ',');
    }

    /**
     * @param $languageCode
     * @param $languageArray
     * @param $domainUrl
     * @return string
     */
    public function fLanguageDomain($languageCode, $languageArray, $domainUrl): string
    {
        $domainStr = '';
        $frontDomainArray = defined('SHOP_FONT_DOMAIN') ? SHOP_FONT_DOMAIN : [];
        foreach ($languageArray as $language) {
            if ($languageCode == $language) {
                if (!empty($domainUrl)) $domainStr .= "'".$domainUrl."' => '".$language."',";
                else continue;
            }
            else {
                if (in_array($language, $frontDomainArray)) $domainStr .= "'".array_search($language, $frontDomainArray)."' => '".$language."',";
            }
        }

        return rtrim($domainStr, ',');
    }
}