<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Admin\Form;

use Admin\Data\Config;
use Laminas\Form\Form;

class DeliveryForm extends Form
{
    public function __construct($name = 'delivery-form', $options = [])
    {
        parent::__construct($name, $options);
        $this->setAttribute('method', 'post');
        $this->setAttribute('class', 'form-horizontal');

        $this->addElements();
        $this->addInputFilter();
    }

    protected function addElements()
    {
        foreach (SHOP_LANGUAGE as $language) {
            $this->add([
                'type'  => 'text',
                'name'  => 'deliveryName'.$language,
                'attributes'    => [
                    'id'            => 'deliveryName'.$language,
                    'class'         => 'form-control'
                ]
            ]);

            $this->add([
                'type'  => 'textarea',
                'name'  => 'deliveryInfo'.$language,
                'attributes'    => [
                    'id'            => 'deliveryInfo'.$language,
                    'class'         => 'form-control',
                    'rows'          => 3
                ]
            ]);
        }

        $this->add([
            'type'  => 'text',
            'name'  => 'deliveryUrl',
            'attributes'    => [
                'id'            => 'deliveryUrl',
                'class'         => 'form-control'
            ]
        ]);

        $this->add([
            'type'  => 'select',
            'name'  => 'deliveryNameCode',
            'attributes'    => [
                'id'            => 'deliveryNameCode',
                'class'         => 'form-control select2'
            ]
        ]);

        $this->add([
            'type'  => 'select',
            'name'  => 'cashOnDelivery',
            'attributes'    => [
                'id'            => 'cashOnDelivery',
                'class'         => 'form-control'
            ]
        ]);

        $this->add([
            'type'  => 'checkbox',
            'name'  => 'deliveryState',
            'attributes' => [
                'value' => 1
            ]
        ]);

        $this->add([
            'type'  => 'number',
            'name'  => 'deliverySort',
            'attributes'    => [
                'id'            => 'deliverySort',
                'class'         => 'form-control',
                'value'         => 255
            ]
        ]);
    }

    protected function addInputFilter()
    {
        $inputFilter = $this->getInputFilter();

        foreach (SHOP_LANGUAGE as $language) {
            $inputFilter->add([
                'name'      => 'deliveryName'.$language,
                'required'  => true,
                'filters'   => [
                    ['name' => 'StringTrim'],
                    ['name' => 'StripTags']
                ]
            ]);

            $inputFilter->add([
                'name'      => 'deliveryInfo'.$language,
                'required'  => false,
                'filters'   => [
                    ['name' => 'StringTrim'],
                    ['name' => 'StripTags']
                ]
            ]);
        }

        $inputFilter->add([
            'name'      => 'deliveryUrl',
            'required'  => false,
            'filters'   => [
                ['name' => 'StringTrim'],
                ['name' => 'StripTags']
            ]
        ]);

        $inputFilter->add([
            'name'      => 'deliveryNameCode',
            'required'  => false
        ]);

        $inputFilter->add([
            'name'      => 'cashOnDelivery',
            'required'  => false
        ]);

        $inputFilter->add([
            'name'      => 'deliveryState',
            'required'  => false,
            'validators'=> [
                [
                    'name'      => 'InArray',
                    'options'   => [
                        'haystack'  => [0, 1]
                    ]
                ]
            ]
        ]);

        $inputFilter->add([
            'name'      => 'deliverySort',
            'required'  => true,
            'filters'   => [
                ['name' => 'ToInt']
            ],
            'validators'=> [
                [
                    'name'      => 'GreaterThan',
                    'options'   => [
                        'min'   => 0
                    ]
                ]
            ]
        ]);

    }
}