<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Cms\Form;

use Laminas\Form\Form;

class CmsForm extends Form
{
    public function __construct($name = 'cms-form', $options = [])
    {
        parent::__construct($name, $options);
        $this->setAttribute('method', 'post');
        $this->setAttribute('class', 'form-horizontal');

        $this->addElements();
        $this->addInputFilter();
    }

    protected function addElements()
    {
        foreach (SHOP_LANGUAGE as $language) {
            $this->add([
                'type'  => 'text',
                'name'  => 'cmsTitle'.$language,
                'attributes'    => [
                    'id'            => 'cmsTitle'.$language,
                    'class'         => 'form-control'
                ]
            ]);

            $this->add([
                'type'  => 'textarea',
                'name'  => 'cmsBody'.$language,
                'attributes'    => [
                    'id'            => 'cmsBody'.$language,
                    'class'         => 'form-control'
                ]
            ]);

            $this->add([
                'type'  => 'text',
                'name'  => 'cmsExtendTitle'.$language,
                'attributes'    => [
                    'id'            => 'cmsExtendTitle'.$language,
                    'class'         => 'form-control'
                ]
            ]);

            $this->add([
                'type'  => 'text',
                'name'  => 'cmsKeywords'.$language,
                'attributes'    => [
                    'id'            => 'cmsKeywords'.$language,
                    'class'         => 'form-control'
                ]
            ]);

            $this->add([
                'type'  => 'textarea',
                'name'  => 'cmsDescription'.$language,
                'attributes'    => [
                    'id'            => 'cmsDescription'.$language,
                    'class'         => 'form-control',
                    'rows'          => 4
                ]
            ]);
        }

        $this->add([
            'type'  => 'select',
            'name'  => 'cmsClassId',
            'attributes'    => [
                'id'            => 'cmsClassId',
                'class'         => 'form-control'
            ]
        ]);

        $this->add([
            'type'  => 'text',
            'name'  => 'cmsWriter',
            'attributes'    => [
                'id'            => 'cmsWriter',
                'class'         => 'form-control'
            ]
        ]);

        $this->add([
            'type'  => 'text',
            'name'  => 'cmsUrl',
            'attributes'    => [
                'id'            => 'cmsUrl',
                'class'         => 'form-control'
            ]
        ]);

        $this->add([
            'type'  => 'text',
            'name'  => 'cmsAddTime',
            'attributes'    => [
                'id'            => 'cmsAddTime',
                'class'         => 'form-control'
            ]
        ]);

        $this->add([
            'type'  => 'checkbox',
            'name'  => 'cmsState',
            'attributes'    => [
                'id'            => 'cmsState',
                'value'         => 1
            ]
        ]);

        $this->add([
            'type'  => 'number',
            'name'  => 'cmsSort',
            'attributes'    => [
                'id'        => 'cmsSort',
                'class'     => 'form-control',
                'value'     => 255,
                'min'       => 1
            ]
        ]);
    }

    protected function addInputFilter()
    {
        $inputFilter = $this->getInputFilter();

        foreach (SHOP_LANGUAGE as $language) {
            $inputFilter->add([
                'name'      => 'cmsTitle'.$language,
                'required'  => true,
                'filters'   => [
                    ['name' => 'StringTrim'],
                    ['name' => 'StripTags']
                ],
                'validators'=> [
                    [
                        'name'      => 'StringLength',
                        'options'   => [
                            'min'   => 1,
                            'max'   => 200
                        ]
                    ]
                ]
            ]);

            $inputFilter->add([
                'name'      => 'cmsBody'.$language,
                'required'  => false,
                'filters'   => [
                    ['name' => 'StringTrim']
                ]
            ]);

            $inputFilter->add([
                'name'      => 'cmsExtendTitle'.$language,
                'required'  => false,
                'filters'   => [
                    ['name' => 'StringTrim'],
                    ['name' => 'StripTags']
                ],
                'validators'=> [
                    [
                        'name'      => 'StringLength',
                        'options'   => [
                            'min'   => 1,
                            'max'   => 200
                        ]
                    ]
                ]
            ]);

            $inputFilter->add([
                'name'      => 'cmsKeywords'.$language,
                'required'  => false,
                'filters'   => [
                    ['name' => 'StringTrim'],
                    ['name' => 'StripTags']
                ],
                'validators'=> [
                    [
                        'name'      => 'StringLength',
                        'options'   => [
                            'min'   => 1,
                            'max'   => 200
                        ]
                    ]
                ]
            ]);

            $inputFilter->add([
                'name'      => 'cmsDescription'.$language,
                'required'  => false,
                'filters'   => [
                    ['name' => 'StringTrim'],
                    ['name' => 'StripTags']
                ],
                'validators'=> [
                    [
                        'name'      => 'StringLength',
                        'options'   => [
                            'min'   => 1,
                            'max'   => 500
                        ]
                    ]
                ]
            ]);
        }

        $inputFilter->add([
            'name'      => 'cmsClassId',
            'required'  => true,
            'filters'   => [
                ['name' => 'ToInt']
            ],
            'validators'=> [
                [
                    'name'      => 'GreaterThan',
                    'options'   => [
                        'min'   => 0
                    ]
                ]
            ]
        ]);

        $inputFilter->add([
            'name'      => 'cmsWriter',
            'required'  => false,
            'filters'   => [
                ['name' => 'StringTrim'],
                ['name' => 'StripTags']
            ]
        ]);

        $inputFilter->add([
            'name'      => 'cmsUrl',
            'required'  => false,
            'filters'   => [
                ['name' => 'StringTrim'],
                ['name' => 'StripTags']
            ]
        ]);

        $inputFilter->add([
            'name'      => 'cmsAddTime',
            'required'  => true,
            'filters'   => [
                ['name' => 'StringTrim'],
                ['name' => 'StripTags']
            ]
        ]);

        $inputFilter->add([
            'name'      => 'cmsState',
            'required'  => false,
            'validators'=> [
                [
                    'name'      => 'InArray',
                    'options'   => [
                        'haystack'  => [0, 1]
                    ]
                ]
            ]
        ]);

        $inputFilter->add([
            'name'      => 'cmsSort',
            'required'  => true,
            'filters'   => [
                ['name' => 'ToInt']
            ],
            'validators'=> [
                [
                    'name'      => 'GreaterThan',
                    'options'   => [
                        'min'   => 0
                    ]
                ]
            ]
        ]);
    }
}