<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Goods\Repository;

use Doctrine\ORM\EntityRepository;
use Doctrine\ORM\Query\Expr\Join;
use Goods\Entity\GoodsInSpecGroupTag;
use Goods\Entity\GoodsTag;
use Goods\Entity\GoodsTagContent;
use Goods\Entity\GoodsTagGroup;
use Goods\Entity\GoodsTagGroupContent;

class GoodsInSpecGroupTagRepository extends EntityRepository
{
    /**
     * 后台添加编辑商品时的规格组获取
     * @param $goodsId
     * @return array
     */
    public function findGoodsSpecGroupTag($goodsId)
    {
        $query = $this->getEntityManager()->createQueryBuilder()
            ->select('s')
            ->addSelect("(SELECT c.tagGroupName FROM ".GoodsTagGroupContent::class." AS c WHERE c.tagGroupId=t.tagGroupId AND c.languageCode='".SHOP_FONT_LANGUAGE."') AS tagGroupName")
            ->from(GoodsInSpecGroupTag::class, 's')
            ->innerJoin(GoodsTagGroup::class, 't', Join::WITH, 's.groupId=t.tagGroupId')
            ->where('s.goodsId = :goodsId')->setParameter('goodsId', $goodsId)
            ->orderBy('t.tagGroupSort', ' ASC')->addOrderBy('t.tagGroupId', 'ASC');

        $specGroupTag = $query->getQuery()->getResult();
        $specGroupTagArray = [];
        if($specGroupTag) foreach ($specGroupTag as $groupTagValue) {
            $specGroupTagArray[$groupTagValue[0]->getGroupId()] = $groupTagValue[0]->valuesArray();
            $specGroupTagArray[$groupTagValue[0]->getGroupId()]['selectedTagId'] = explode(',', $specGroupTagArray[$groupTagValue[0]->getGroupId()]['selectedTagId']);
            $specGroupTagArray[$groupTagValue[0]->getGroupId()]['tagGroupName'] = $groupTagValue['tagGroupName'];
        }

        return $specGroupTagArray;
    }

    /**
     * 商品规格名称数组，tagName 数组
     * @param $goodsId
     * @return array
     */
    public function findGoodsSpecTagArray($goodsId)
    {
        $query = $this->getEntityManager()->createQueryBuilder()
            ->select('s')
            ->from(GoodsInSpecGroupTag::class, 's')
            ->where('s.goodsId = :goodsId')->setParameter('goodsId', $goodsId);

        $specGroupTag = $query->getQuery()->getResult();
        $specTagIdStr = '';
        if($specGroupTag) foreach ($specGroupTag as $groupTagValue) {
            $specTagIdStr .= $groupTagValue->getSelectedTagId() . ',';
        }

        $tagArray = [];
        $tagIdArray = array_filter(explode(',', rtrim($specTagIdStr, ',')));
        if(!empty($tagIdArray)) {
            $query = $this->getEntityManager()->createQueryBuilder();
            $query->select('t')->from(GoodsTagContent::class, 't')->where($query->expr()->in('t.tagId', $tagIdArray))->andWhere('t.languageCode = :languageCode')->setParameter('languageCode', SHOP_FONT_LANGUAGE);
            $tagResult = $query->getQuery()->getResult();
            if($tagResult) foreach ($tagResult as $tagValue) {
                $tagArray[ $tagValue->getTagId()] = $tagValue->getTagName();
            }
        }

        return $tagArray;
    }
    /*==============================================商城前台==============================================*/

    /**
     * 前台商品详情的规格组及规格信息
     * @param $goodsId
     * @param $languageCode
     * @return array
     */
    public function findShopGoodsSpecGroupTag($goodsId, $languageCode)
    {
        $query = $this->getEntityManager()->createQueryBuilder()
            ->select('s')
            ->addSelect("(SELECT c.tagGroupName FROM ".GoodsTagGroupContent::class." AS c WHERE c.tagGroupId=t.tagGroupId AND c.languageCode='".$languageCode."') AS tagGroupName")
            ->from(GoodsInSpecGroupTag::class, 's')
            ->innerJoin(GoodsTagGroup::class, 't', Join::WITH, 's.groupId=t.tagGroupId')
            ->where('s.goodsId = :goodsId')->setParameter('goodsId', $goodsId)
            ->orderBy('t.tagGroupSort', ' ASC')->addOrderBy('t.tagGroupId', 'ASC');

        $specGroupTag = $query->getQuery()->getResult();
        $specGroupTagArray = [];
        $specTagIdStr = '';
        if($specGroupTag) foreach ($specGroupTag as $groupTagValue) {
            $specGroupTagArray[$groupTagValue[0]->getGroupId()] = $groupTagValue[0]->valuesArray();
            $specGroupTagArray[$groupTagValue[0]->getGroupId()]['tagGroupName'] = $groupTagValue['tagGroupName'];
            $specTagIdStr .= $specGroupTagArray[$groupTagValue[0]->getGroupId()]['selectedTagId'] . ',';
        }

        $tagIdArray = array_filter(explode(',', rtrim($specTagIdStr, ',')));
        if(!empty($tagIdArray)) {
            $query = $this->getEntityManager()->createQueryBuilder();
            $query->select('t')
                ->from(GoodsTag::class, 't')
                ->addSelect("(SELECT c.tagName FROM ".GoodsTagContent::class." AS c WHERE c.tagId=t.tagId AND c.languageCode='".$languageCode."') AS tagName")
                ->where($query->expr()->in('t.tagId', $tagIdArray))->orderBy('t.tagSort', 'ASC')->addOrderBy('t.tagId', 'ASC');
            $tagResult = $query->getQuery()->getResult();
            if($tagResult) foreach ($tagResult as $tagValue) {
                if(isset($specGroupTagArray[$tagValue[0]->getTagGroupId()])) {
                    $specGroupTagArray[$tagValue[0]->getTagGroupId()]['tagList'][] = ['tagId' => $tagValue[0]->getTagId(), 'tagName' => $tagValue['tagName']];
                }
            }
        }

        return $specGroupTagArray;
    }
}