<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Operation\Service;

use Doctrine\ORM\EntityManager;
use Operation\Entity\RechargeCodeRuleContent;

class RechargeCodeRuleContentManager
{
    private $entityManager;

    public function __construct(
        EntityManager $entityManager
    )
    {
        $this->entityManager = $entityManager;
    }

    /**
     * 添加或者编辑充值规则内容
     * @param array $data
     * @param $codeRuleId
     * @return void
     * @throws \Doctrine\ORM\ORMException
     * @throws \Doctrine\ORM\OptimisticLockException
     */
    public function addOrEditRechargeCodeRuleContent(array $data, $codeRuleId)
    {
        foreach (SHOP_LANGUAGE as $language) {
            $ruleContent = $this->entityManager->getRepository(RechargeCodeRuleContent::class)->findOneBy(['codeRuleId' => $codeRuleId, 'languageCode' => $language]);
            if ($ruleContent) {
                $ruleContent->setCodeRuleTitle($data['codeRuleTitle'.$language]);
            } else {
                $ruleContent = new RechargeCodeRuleContent();
                $ruleContent->setLanguageCode($language);
                $ruleContent->setCodeRuleId($codeRuleId);
                $ruleContent->setCodeRuleTitle($data['codeRuleTitle'.$language]);

                $this->entityManager->persist($ruleContent);
            }

            $this->entityManager->flush();
        }
    }

    /**
     * 删除充值规则内容
     * @param $codeRuleId
     * @return void
     */
    public function deleteRechargeCodeRuleContent($codeRuleId)
    {
        $qb = $this->entityManager->createQueryBuilder();
        $qb->delete(RechargeCodeRuleContent::class, 'c')->where($qb->expr()->eq('c.codeRuleId', $codeRuleId));
        $qb->getQuery()->execute();
    }
}