<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Sales\Controller;

use Admin\Controller\AdminActionController;
use Admin\Data\Common;
use Doctrine\ORM\EntityManager;
use Laminas\Mvc\I18n\Translator;
use Sales\Entity\OrderGoods;
use Sales\Entity\OrderGoodsReturn;
use Sales\Form\OrderGoodsReturnForm;
use Sales\Form\SearchOrderGoodsReturnForm;
use Sales\Service\OrderGoodsManager;
use Sales\Service\OrderGoodsReturnManager;
use Sales\Service\OrderManager;
use User\Entity\User;
use User\Service\BalanceLogManager;
use User\Service\UserManager;

class SalesServiceController extends AdminActionController
{
    private $translator;
    private $entityManager;
    private $orderGoodsReturnManager;
    private $balanceLogManager;
    private $userManager;
    private $orderManager;
    private $orderGoodsManager;

    public function __construct(
        Translator      $translator,
        EntityManager   $entityManager,
        OrderGoodsReturnManager $orderGoodsReturnManager,
        BalanceLogManager $balanceLogManager,
        UserManager     $userManager,
        OrderManager    $orderManager,
        OrderGoodsManager $orderGoodsManager
    )
    {
        $this->translator       = $translator;
        $this->entityManager    = $entityManager;
        $this->orderGoodsReturnManager = $orderGoodsReturnManager;
        $this->balanceLogManager= $balanceLogManager;
        $this->userManager      = $userManager;
        $this->orderManager     = $orderManager;
        $this->orderGoodsManager= $orderGoodsManager;
    }

    /**
     * 退换货列表
     * @return array|\Laminas\View\Model\ViewModel
     */
    public function indexAction()
    {
        $page = (int) $this->params()->fromQuery('page', 1);

        $search = [];
        $searchForm = new SearchOrderGoodsReturnForm();
        $searchForm->get('return_type')->setValueOptions(Common::orderGoodsReturnType($this->translator));
        $searchForm->get('return_state')->setValueOptions(Common::orderGoodsReturnState($this->translator));
        if($this->getRequest()->isGet()) {
            $data = $this->params()->fromQuery();
            $searchForm->setData($data);
            if($searchForm->isValid()) $search = $searchForm->getData();
        }

        $query      = $this->entityManager->getRepository(OrderGoodsReturn::class)->findOrderReturnList($search);
        $paginator  = $this->adminCommon()->shopPaginator($query, $page);

        return ['goodsReturnList' => $paginator, 'searchForm' => $searchForm];
    }

    /**
     * 审核退换货信息
     * @return array|\Laminas\Http\Response
     */
    public function editAction()
    {
        $returnId = (int) $this->params()->fromRoute('id', -1);
        $returnInfo = $this->entityManager->getRepository(OrderGoodsReturn::class)->findOneBy(['returnId' => $returnId, 'returnState' => 1]);
        if ($returnInfo == null) return $this->adminCommon()->toReferer();

        $orderGoodsInfo = $this->entityManager->getRepository(OrderGoods::class)->findOrderGoodsAndOrder($returnInfo->getOrderGoodsId());

        $queryData = $this->params()->fromQuery();

        $form = new OrderGoodsReturnForm();
        $form->get('returnState')->setValueOptions(Common::orderGoodsReturnState($this->translator));

        if($this->getRequest()->isPost()) {
            $data = $this->params()->fromPost();
            $form->setData($data);
            if ($form->isValid()) {
                $data = $form->getData();
                if ($data['returnState'] == 1) return $this->redirect()->toRoute('sales-service');

                $this->entityManager->beginTransaction();
                try {
                    if ($returnInfo->getReturnType() != 3 && $data['returnState'] == 2 && $returnInfo->getRefundPayType() == 'originalPay') {//原路退款
                        $paymentConfig = Common::getPaymentConfig($orderGoodsInfo['paymentCode']);
                        if (!isset($paymentConfig['originalRefundState']['checked']) || $paymentConfig['originalRefundState']['checked'] != 1 || $paymentConfig['paymentState']['checked'] != 1) {
                            $this->flashMessenger()->addWarningMessage($this->translator->translate('该订单对应的支付方式没有启用原路退款!'));
                            return $this->adminCommon()->toReferer();
                        }
                        if (empty($orderGoodsInfo['outTradeNo'])) {
                            $this->flashMessenger()->addWarningMessage($this->translator->translate('该订单不存在商户订单号，不能进行退款!'));
                            return $this->adminCommon()->toReferer();
                        }

                        $payResult = Common::getPaymentService($orderGoodsInfo['paymentCode'])->orderPaymentRefund(['outTradeNo' => $orderGoodsInfo['outTradeNo'], 'orderSn' => $returnInfo->getOrderSn(), 'totalFee' => $orderGoodsInfo['orderAmount'], 'refundFee' => $returnInfo->getReturnAmount(), 'refundId' => $returnInfo->getReturnId(), 'refundDesc' => $this->translator->translate('商品退款，订单编号：') . $returnInfo->getOrderSn()], 'orderGoods');
                        if (isset($payResult['refundState']) && $payResult['refundState'] && !empty($payResult['outRefundNo'])) {
                            $data['outRefundNo'] = $payResult['outRefundNo'];
                        } else {
                            $this->flashMessenger()->addWarningMessage($this->translator->translate('原路退款失败!'));
                            return $this->adminCommon()->toReferer();
                        }
                    }

                    $returnInfo = $this->orderGoodsReturnManager->editGoodsReturn($data, $returnInfo);
                    if ($data['returnState'] == 2) {
                        $this->orderManager->updateOrderReturnType($returnInfo->getReturnType(), $returnInfo->getOrderId());
                        $this->orderGoodsManager->editOrderGoods(['goodsStatus' => -10], $this->entityManager->getRepository(OrderGoods::class)->findOneBy(['orderGoodsId' => $returnInfo->getOrderGoodsId()]));
                    }
                    if ($returnInfo->getReturnType() != 3 && $returnInfo->getRefundPayType() == 'balancePay' && $data['returnState'] == 2) {//余额退款
                        $currency       = Common::configValue($orderGoodsInfo['currencyCode'], 'currency');
                        $userInfo       = $this->entityManager->getRepository(User::class)->findOneBy(['userId' => $returnInfo->getUserId()]);
                        $returnAmount   = number_format($returnInfo->getReturnAmount()/$currency['rate'], 2, '.', '');
                        $userMoney      = $userInfo->getUserMoney() + $returnAmount;
                        $this->balanceLogManager->addBalanceLog([
                            'userId'    => $returnInfo->getUserId(),
                            'userName'  => $returnInfo->getUserName(),
                            'balanceChangeType' => 5,
                            'balanceChangeNum'  => $returnAmount,
                            'balanceChangedAmount' => $userMoney,
                            'balanceChangeTime' => time(),
                            'balanceChangeInfo' => 'Order No：' . $returnInfo->getOrderSn()
                        ]);
                        $this->userManager->updateUserMoney($userMoney, $userInfo);
                    }

                    $this->getEventManager()->trigger('backstage-order.sales-service.post', $this, ['orderGoodsInfo' => $orderGoodsInfo, 'returnInfo' => $returnInfo, 'orderId' => $returnInfo->getOrderId(), 'orderSn' => $returnInfo->getOrderSn(), 'returnState' => $data['returnState']]);

                    $this->entityManager->commit();
                    $this->adminCommon()->addOperLog($this->translator->translate('售后申请处理成功!'), $this->translator->translate('售后管理'));
                } catch (\Exception $e) {
                    $this->entityManager->rollback();
                    $this->flashMessenger()->addWarningMessage($this->translator->translate('售后申请处理失败!'));
                }
                return $this->redirect()->toRoute('sales-service', [], ['query' => $queryData]);
            }
        }

        return ['returnInfo' => $returnInfo, 'orderGoodsInfo' => $orderGoodsInfo, 'form' => $form, 'queryData' => $queryData];
    }

    /**
     * 查看退换货结果详情
     * @return array
     */
    public function viewAction()
    {
        $returnId = (int) $this->params()->fromRoute('id', -1);
        $returnInfo = $this->entityManager->getRepository(OrderGoodsReturn::class)->findOneBy(['returnId' => $returnId]);
        if ($returnInfo == null || $returnInfo->getReturnState() == 1) return $this->adminCommon()->toReferer();

        $queryData = $this->params()->fromQuery();

        $orderGoodsInfo = $this->entityManager->getRepository(OrderGoods::class)->findOrderGoodsAndOrder($returnInfo->getOrderGoodsId());

        return ['returnInfo' => $returnInfo, 'orderGoodsInfo' => $orderGoodsInfo, 'queryData' => $queryData];
    }

    /**
     * 删除退换货信息
     * @return mixed
     * @throws \Doctrine\ORM\ORMException
     * @throws \Doctrine\ORM\OptimisticLockException
     */
    public function deleteAction()
    {
        if(!$this->adminCommon()->validatorCsrf()) return $this->adminCommon()->toReferer();

        $returnId = (int) $this->params()->fromRoute('id', -1);
        $returnInfo = $this->entityManager->getRepository(OrderGoodsReturn::class)->findOneBy(['returnId' => $returnId, 'returnState' => 1]);
        if ($returnInfo == null) {
            $this->flashMessenger()->addWarningMessage($this->translator->translate('该信息状态不允许删除!'));
            return $this->adminCommon()->toReferer();
        }

        $this->orderGoodsReturnManager->deleteGoodsReturn($returnInfo);

        $this->adminCommon()->addOperLog($this->translator->translate('退换货信息删除成功!'), $this->translator->translate('售后管理'));
        return $this->adminCommon()->toReferer();
    }
}