<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Shop\Form;

use Admin\Data\Config;
use Laminas\Form\Form;
use Shop\Validator\PhoneCaptchaValidator;
use User\Validator\UserExistsValidator;
use User\Validator\UserPhoneExistsValidator;

class UserPhoneRegisterForm extends Form
{
    private $phoneArea;
    private $entityManager;
    public $inputFilter;

    public function __construct(array $phoneArea, $entityManager, $name = 'user-phone-register-form', $options = [])
    {
        parent::__construct($name, $options);

        $this->setAttribute('method', 'post');

        $this->phoneArea        = $phoneArea;
        $this->entityManager    = $entityManager;

        $this->addElements();
        $this->inputFilter = $this->addInputFilter();
    }

    protected function addElements()
    {
        $this->add([
            'type'  => 'text',
            'name'  => 'userName',
            'attributes'=> [
                'id'    => 'userName'
            ]
        ]);

        if(count($this->phoneArea) == 1) {
            $this->add([
                'type'  => 'hidden',
                'name'  => 'areaCode',
                'attributes'=> [
                    'id'    => 'areaCode',
                    'value' => $this->phoneArea[0]['areaCode']
                ]
            ]);
        } else {
            $this->add([
                'type'  => 'select',
                'name'  => 'areaCode',
                'attributes'=> [
                    'id'    => 'areaCode',
                    'value' => $this->phoneArea['default']
                ],
                'options' => [
                    'value_options' => $this->phoneArea['list']
                ]
            ]);
        }

        $this->add([
            'type'  => 'text',
            'name'  => 'userPhone',
            'attributes'=> [
                'id'    => 'userPhone'
            ]
        ]);

        $this->add([
            'type'  => 'text',
            'name'  => 'phoneCaptcha',
            'attributes'=> [
                'id'    => 'phoneCaptcha'
            ]
        ]);

        $this->add([
            'type'  => 'hidden',
            'name'  => 'httpReferer',
            'attributes' => [
                'id'    => 'httpReferer'
            ]
        ]);

        $this->add([
            'type'  => 'checkbox',
            'name'  => 'agreement',
            'attributes'    => [
                'id' => 'agreement'
            ]
        ]);

        $this->add([
            'type'  => 'csrf',
            'name'  => 'shopCsrf',
            'options' => [
                'csrf_options' => [
                    'timeout'  => Config::SHOP_POST_TOKEN_TIMEOUT
                ]
            ]
        ]);
    }

    protected function addInputFilter()
    {
        $inputFilter = $this->getInputFilter();

        $inputFilter->add([
            'name'      => 'userName',
            'required'  => true,
            'filters'   => [
                ['name' => 'StringTrim'],
                ['name' => 'StripTags']
            ],
            'validators'=> [
                [
                    'name'      => 'StringLength',
                    'options'   => [
                        'min'   => 1,
                        'max'   => 100
                    ]
                ],
                [
                    'name'      => UserExistsValidator::class,
                    'options'    => [
                        'entityManager' => $this->entityManager,
                        'userInfo'      => null
                    ]
                ]
            ]
        ]);

        $inputFilter->add([
            'name'      => 'userPhone',
            'required'  => true,
            'filters'   => [
                ['name' => 'StringTrim'],
                ['name' => 'StripTags']
            ],
            'validators'=> [
                [
                    'name' => UserPhoneExistsValidator::class,
                    'options'   => [
                        'entityManager' => $this->entityManager,
                        'userInfo'      => null
                    ]
                ],
                [
                    'name'      => 'StringLength',
                    'options'   => [
                        'min'   => 1,
                        'max'   => 30
                    ]
                ]
            ]
        ]);

        $inputFilter->add([
            'name'      => 'phoneCaptcha',
            'required'  => true,
            'filters'   => [
                ['name' => 'ToInt']
            ],
            'validators'=> [
                [
                    'name' => PhoneCaptchaValidator::class
                ]
            ]
        ]);

        $inputFilter->add([
            'name'      => 'agreement',
            'required'  => true,
            'filters'   => [
                ['name' => 'ToInt']
            ],
            'validators'=> [
                [
                    'name'      => 'InArray',
                    'options'   => [
                        'haystack'  => [1]
                    ]
                ]
            ]
        ]);

        $inputFilter->add([
            'name'      => 'httpReferer',
            'required'  => false,
            'filters'   => [
                ['name' => 'StringTrim']
            ]
        ]);

        return $inputFilter;
    }
}