<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Shop\Validator;

use Admin\Entity\SelfLocation;
use Laminas\I18n\Translator\Translator;
use Laminas\Validator\AbstractValidator;

class SelfLocationValidator extends AbstractValidator
{
    const PLEASE_SELECT         = 'pleaseSelect';
    const NOT_SCALAR            = 'notScalar';
    const LOCATION_NOT_EXISTS   = 'locationNotExists';

    protected $messageTemplates = [];

    protected $entityManager;

    public function __construct($options = null)
    {
        if(isset($options['entityManager']))    $this->entityManager = $options['entityManager'];

        $trans = new Translator();
        $this->messageTemplates = [
            self::NOT_SCALAR    => $trans->translate("这不是一个标准输入值"),
            self::PLEASE_SELECT => $trans->translate("请选择自提点"),
            self::LOCATION_NOT_EXISTS => $trans->translate("您选择的自提点不存在")
        ];

        parent::__construct($options);
    }

    public function isValid($value)
    {
        if(!is_scalar($value)) {
            $this->error(self::NOT_SCALAR);
            return false;
        }

        if($value == 0) {
            $this->error(self::PLEASE_SELECT);
            return false;
        }

        $isValid = true;

        $addressInfo = $this->entityManager->getRepository(SelfLocation::class)->findOneBy(['locationId' => $value, 'locationState' => 1]);
        if($addressInfo == null) {
            $isValid = false;
            $this->error(self::LOCATION_NOT_EXISTS);
        }

        return $isValid;
    }
}