<?php
/**
 * DBShop 电子商务系统
 *
 * ==========================================================================
 * @link      https://www.dbshop.net/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbshop.net/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace User\Service\Common\AppLogin;

use Admin\Data\Common;
use Laminas\Json\Json;
use Laminas\Session\Container;

class FacebookLogin
{
    const ACCOUNTS_AUTH_URL     = 'https://www.facebook.com/v12.0/dialog/oauth';
    const AUTH_ACCESS_TOKEN_URL = 'https://graph.facebook.com/v12.0/oauth/access_token';
    const AUTH_USERINFO_URL     = 'https://graph.facebook.com/v12.0/me';

    public $redirectUri;

    private $customerConfig = [];
    private $loginSession;

    public function __construct()
    {
        $this->customerConfig   = Common::readConfigFile('customer');
        $this->loginSession     = new Container('facebookSession');
    }

    public function toLogin()
    {
        $loginKey = [
            'client_id'                 => $this->customerConfig['facebook_app_id'],
            'redirect_uri'              => $this->redirectUri,
            'state'                     => md5(uniqid(rand(), TRUE)),
        ];

        $this->loginSession->offsetSet('facebookState', $loginKey['state']);

        header("Location: " . $this->combineUrl(self::ACCOUNTS_AUTH_URL, $loginKey));
        exit();
    }

    public function loginCallBack()
    {
        if (isset($_GET['state'])) {
            if ($this->loginSession->offsetGet('facebookState') != $_GET['state']) {
                exit('<h2>The state does not match. You may be a victim of CSRF.</h2>');
            }

            $loginKey = [
                'client_id'     => $this->customerConfig['facebook_app_id'],
                'redirect_uri'  => $this->redirectUri,
                'client_secret' => $this->customerConfig['facebook_app_key'],
                'code'          => $_GET['code']
            ];

            $response   = Common::httpGet($this->combineUrl(self::AUTH_ACCESS_TOKEN_URL, $loginKey));
            $result     = Json::decode($response, Json::TYPE_ARRAY);
            if (!empty($result['access_token'])) {
                $loginKey = [
                    'fields' => 'id,name',
                    'access_token' => $result['access_token']
                ];
                $response   = Common::httpGet($this->combineUrl(self::AUTH_USERINFO_URL, $loginKey));
                $array      = Json::decode($response, Json::TYPE_ARRAY);
                if (isset($array['id']) && isset($array['name'])) {
                    $this->loginSession->offsetSet('facebookOpenId', $array['id']);
                    $this->loginSession->offsetSet('facebookName', $array['name']);
                } else exit($response);
            } else exit($response);
        }
    }

    /**
     * openId
     * @return mixed|null
     */
    public function openId()
    {
        return $this->loginSession->offsetGet('facebookOpenId');
    }

    /**
     * unionId
     * @return string
     */
    public function unionId()
    {
        return '';
    }

    /**
     * 账户信息
     * @return array
     */
    public function loginUserInfo()
    {
        return ['nickname' => $this->loginSession->offsetGet('facebookName')];
    }

    /**
     * 清除使用过的session
     */
    public function clearOtherLoginSession()
    {
        $this->loginSession->getManager()->getStorage()->clear($this->loginSession->getName());
    }

    /**
     * 拼接Url
     * @param $baseUrl
     * @param $keyArray
     * @return string
     */
    private function combineUrl($baseUrl, $keyArray)
    {
        return $baseUrl . '?' . Common::toUrlParams($keyArray);
    }
}